@@ -25,9 +25,10 @@ tvmvarsampler <- function(coefarray, # v x v2 x cat(v) x cat(v2) x lag array x N
   if(dim(coefarray)[1] != length(level)) stop('Dimensions for variables in coefarray have to match the number of specified levels.')
   if(dim(coefarray)[1] != dim(coefarray)[2]) stop('The first two dimensions specifying the cross-lagged effects in coefarray have to have the same dimensionality.')
   
-  if(class(thresholds) != 'list') stop('The thresholds have to be provided via a list with p entries. See ?tvmvarsampler')
-  if(class(sds) != 'matrix') stop('The standard deviations of Gaussian variables have to be provided via a p x n matrix.')
-  
+
+  if(!inherits(thresholds, "list")) stop('The thresholds have to be provided via a list with p entries. See ?tvmvarsampler')
+  if(!inherits(sds, "matrix")) stop('The standard deviations of Gaussian variables have to be provided via a p x n matrix.')
+
   
   # ---------- Fill in Defaults ----------
   
